# Suppress R CMD check warnings for dplyr NSE (Non Standard Evaluation)
utils::globalVariables(
  c(
    "alias",
    "area",
    "area_code",
    "area_code_p",
    "area_name",
    "balanced_export",
    "balanced_import",
    "bilateral_trade",
    "cf",
    "domestic_supply",
    "element",
    "Element",
    "export",
    "feedtype",
    "fill_value",
    "final_value_processed",
    "from_code",
    "groups",
    "import",
    "Imp/Exp",
    "Info_Format",
    "intake",
    "intake_dm",
    "item",
    "Item",
    "item_cbs_code",
    "item_cbs_code_crop",
    "item_cbs_code_processed",
    "item_cbs_code_residue",
    "item_cbs_code_to_process",
    "item_cbs_name",
    "item_code",
    "item_code_cbs",
    "item_processed",
    "item_prod_code",
    "item_prod_name",
    "item_to_process",
    "item_type",
    "live_anim_code",
    "loss",
    "loss_share",
    "Name",
    "No",
    "prefilled",
    "proc",
    "process",
    "proc_cbs_code",
    "proc_group",
    "prod_ygpit_mg",
    "product_fraction",
    "product_residue",
    "proxy_ratio",
    "SACO_link",
    "scaling",
    "seed",
    "sex",
    "source_value",
    "stock_variation",
    "supply",
    "Timeline_End",
    "Timeline_Freq",
    "Timeline_Start",
    "total_export",
    "total_import",
    "total_trade",
    "to_code",
    "Trade",
    "type",
    "unit",
    "value",
    "Value",
    "value_carried_backward",
    "value_carried_forward",
    "value_interpfilled",
    "value_proc",
    "value_proc_raw",
    "value_to_process",
    "year",
    "Year"
  )
)
